@@ -4,24 +4,82 @@ from typing import Union, Type, TypeVar, Generic, List
 
 
 class InvalidChoiceError(Exception):
+    """Raised when the user tries to assign a non-valid variable to :class:`pipcs.Choices` variable."""
     pass
 
+
 class RequiredError(Exception):
+    """Raised if a user doesn't set :class:`pipcs.required` variable in the inherited config. It is also raised if a :class:`pipcs.required` variable is not set during :meth:`pipcs.Config.check_config`.
+    """
     pass
 
+
 class ConditionError(Exception):
     pass
 
+
 T = TypeVar('T')
-class required: ...
+class required:
+    """Mark a variable as required."""
+    pass
 Required = Union[Type[required], T]
 
+
 class Condition(Generic[T]):
+    """To mark a variable as only valid if the condition is hold. It is used combined with :class:`pipcs.Choices`.
+
+    Args:
+        value (T): Value of the variable.
+        comp: Comparison function.
+
+    .. code-block:: python
+
+        from pipcs import Config, Choices, Condition
+
+        config = Config()
+
+        @config('example')
+        class Example():
+            variable: Choices[int] = Choices([1, 2, 3])
+            conditional_variable: Condition[int] = Condition(5, variable==2)
+
+        # Example 1
+        user_config = Config(config)
+
+        @user_config('example')
+        class UserExample():
+            variable = 2
+
+        print(user_config.example.to_dict())
+        # {'variable': 2, 'conditional_variable': 5}
+
+        # Example 2
+        user_config = Config(config)
+
+        @user_config('example')
+        class UserExample():
+            variable = 2
+            conditional_variable = 1
+
+        print(user_config.example.to_dict())
+        # {'variable': 2, 'conditional_variable': 1}
+
+        # Example 3
+        user_config = Config(config)
+
+        @user_config('example')
+        class UserExample():
+            variable = 1
+            conditional_variable = 2
+
+        print(user_config.example.to_dict())
+        # {'variable': 1}
+    """
     def __init__(self, value: T, comp):
         self.value: T = value
         self.comp = comp
 
-    def compare(self, config):
+    def _compare(self, config):
         return self.comp(config)
 
     def __and__(self, other):
@@ -33,8 +91,41 @@ class Condition(Generic[T]):
     def __invert__(self):
         return Condition(self.value, lambda config: not self.comp(config))
 
+
 class Choices(Generic[T]):
-    def __init__(self, choices, default=required):
+    """A class to specify valid choices for the configuration variable. :class:`pipcs.InvalidChoiceError` error will be raised when the user tries to set the variable to a non-valid choice in the inherited configuration.
+
+    Args:
+        choices (List[T]): Valid choices for the configuration variable.
+        default (Required[T]): If the variable is not set by user the default value will be returned.
+
+    .. code-block:: python
+
+        from pipcs import Config, Choices
+
+        config = Config()
+
+        @config('example')
+        class Example():
+            variable: Choices[int] = Choices([1, 2, 3])
+
+        user_config = Config(config)
+
+        @user_config('example')
+        class UserExample():
+            variable = 1
+
+        print(user_config.example.variable)
+        # 1
+
+        user_config = Config(config)
+
+        @user_config('example')
+        class UserExample():
+            variable = 4
+        # Raises: pipcs.pipcs.InvalidChoiceError: 4 is not valid for variable, valid choices: [1, 2, 3]
+    """
+    def __init__(self, choices: List[T], default=required):
         if default is not required:
             if default not in choices:
                 raise InvalidChoiceError('Default value is not in choices')
@@ -42,7 +133,7 @@ class Choices(Generic[T]):
         self.default: Required[T] = default
 
     def __get_value(self, config):
-        value = config.get_config(self._name)
+        value = config.get_value(self._name)
         if isinstance(value, Choices):
             return self.default
         else:
@@ -66,7 +157,14 @@ class Choices(Generic[T]):
     def __ge__(self, other):
         return lambda config: self.__get_value(config) >= other
 
+
 class Config(dict):
+    """Base class to create root configuration.
+
+    Args:
+        dictionary (:obj:`Union[dict, Config]`, optional): If it is a :class:`pipcs.Config`,
+                                                           it will inherit the base configuration.
+    """
     def __init__(self, dictionary={}):
         if isinstance(dictionary, Config):
             self._name = dictionary._name
@@ -75,6 +173,22 @@ class Config(dict):
         super(Config, self).__init__(dictionary)
 
     def check_config(self):
+        """Check configuration if all of the variables are valid.
+
+        .. code-block:: python
+
+            from pipcs import Config, Required, required
+
+            config = Config()
+
+            @config('example')
+            class Example():
+                variable: Required[int] = required
+
+            config.check_config()
+            # Raises: pipcs.pipcs.RequiredError: variable is required!
+        """
+
         for k, v in self.items():
             if isinstance(v, Config):
                 v.check_config()
@@ -91,10 +205,32 @@ class Config(dict):
         elif value is required:
             raise RequiredError(f'{key} is required!')
 
-    def get_config(self, key, check=False):
+    def get_value(self, key, check=False):
+        """
+        Return value of the variable.
+
+        Args:
+            check (bool): If true, the variable will be checked if it is valid or not.
+
+        .. code-block:: python
+
+            from pipcs import Config, Required, required
+
+            config = Config()
+
+            @config('example')
+            class Example():
+                variable: Required[int] = required
+
+            print(config.example.get_value('variable'))
+            # <class 'pipcs.pipcs.required'>
+
+            print(config.example.get_value('variable', check=True))
+            # pipcs.pipcs.RequiredError: variable is required!
+        """
         value = dict.__getitem__(self, key)
         if isinstance(value, Condition):
-            if value.compare(self):
+            if value._compare(self):
                 return value.value
         if check:
             check_value = object.__getattribute__(self, 'check_value')
@@ -102,15 +238,24 @@ class Config(dict):
         return value
 
     def __getitem__(self, key):
-        return self.get_config(key)
+        return self.get_value(key)
 
     def __getattr__(self, key):
         try:
-            return self.get_config(key)
+            return self.get_value(key)
         except KeyError:
             raise AttributeError(key)
 
     def to_dict(self, check=False):
+        """
+        Convert :class:`pipcs.Config` to :class:`dict`.
+        If the :class:`pipcs.Condition` holds for a variable it will be included in the dictionary.
+        :class:`pipcs.Choices` variables will be converted in to their default values.
+
+        Args:
+            check (bool): If true, the variables will be checked if they are valid or not.
+        """
+
         if check:
             self.check_config()
         config_dict = {}
@@ -122,7 +267,7 @@ class Config(dict):
             elif isinstance(v, Choices):
                 config_dict[k] = v.default
             elif isinstance(v, Condition):
-                if v.compare(self):
+                if v._compare(self):
                     config_dict[k] = v.value
             else:
                 config_dict[k] = v
@@ -189,7 +334,7 @@ class Config(dict):
                 elif isinstance(self[k], abc.Mapping):
                     newdict[k] = {**self[k], **v}
                 elif isinstance(self[k], Condition):
-                    if self[k].compare(other):
+                    if self[k]._compare(other):
                         newdict[k] = v
                 elif isinstance(v, Choices):
                     if self[k].default is required:
